@@ -14,8 +14,8 @@
 #'   included in \code{model}.
 #'
 #' @param model_output Should a summary of the model with weights as predictor
-#'   be printed? Default is TRUE, but you may not want it if you are trying to
-#'   declutter a document.
+#'   be printed? Default is FALSE since the output can be very long for
+#'   complex models.
 #'
 #' @param test Which type of test should be used in the ANOVA? The default,
 #'   \code{NULL}, chooses based on the model type ("F" for linear models).
@@ -37,7 +37,8 @@
 #' original; if insignificant, weights are not significantly related to the
 #' result and you can use the more efficient estimation from unweighted OLS.
 #'
-#' It can be helpful to look at the created model using \code{model_output = TRUE}
+#' It can be helpful to look at the created model using
+#' \code{model_output = TRUE}
 #' to see which variables might be the ones affected by inclusion of weights.
 #'
 #' This test can support most GLMs in addition to LMs, a use validated by
@@ -98,22 +99,13 @@
 #' @importFrom stats anova reformulate
 #' @export
 
-wgttest <- function(model, weights, data = NULL, model_output = TRUE,
+wgttest <- function(model, weights, data = NULL, model_output = FALSE,
                     test = NULL,
                     digits = getOption("jtools-digits", default = 3)) {
 
   if (is.null(data)) {
 
-    call <- getCall(model)
-    if (!is.null(call$data)) {
-
-      d <- eval(call$data)
-
-    } else {
-
-      d <- model.frame(model)
-
-    }
+    d <- model.frame(model)
 
   } else {
 
@@ -130,7 +122,8 @@ wgttest <- function(model, weights, data = NULL, model_output = TRUE,
     if (is.numeric(weights)) {
       numeric.input <- TRUE
     } else {
-      stop("weights argument must be either the name of a column in the data frame or a numeric vector.")
+      stop("weights argument must be either the name of a column in the \ndata",
+          " frame or a numeric vector.")
     }
   }
 
@@ -261,10 +254,11 @@ print.wgttest <- function(x, ...) {
 
   }
 
-  cat("\nLower p values indicate greater influence of the weights.")
+  cat("\nLower p values indicate greater influence of the weights.\n")
 
   if (x$model_output == TRUE) {
-    j_summ(x$newmod, model.info = F, model.fit = F)
+    cat("\n")
+    print(j_summ(x$newmod, model.info = F, model.fit = F))
     cat("\n")
   } else {
     cat("\n")
@@ -281,7 +275,8 @@ print.wgttest <- function(x, ...) {
 #'
 #' @param model The fitted model, without weights
 #'
-#' @param data The data frame with the data fed to the fitted model and the weights
+#' @param data The data frame with the data fed to the fitted model and the
+#'  weights
 #'
 #' @param weights The name of the weights column in \code{model}'s data frame
 #'   or a vector of weights equal in length to the number of observations
@@ -334,11 +329,12 @@ print.wgttest <- function(x, ...) {
 #' @export
 #' @importFrom stats resid cor pt sd
 
-pf_sv_test <- function(model, data, weights, sims = 1000,
+pf_sv_test <- function(model, data = NULL, weights, sims = 1000,
                         digits = getOption("jtools-digits", default = 3)) {
 
   if (!requireNamespace("boot", quietly = TRUE)) {
-    stop("This function relies on the boot package. Please install it and try again.",
+    stop("This function relies on the boot package.\n",
+         "Please install it and try again.",
          call. = FALSE)
   }
 
@@ -351,10 +347,14 @@ pf_sv_test <- function(model, data, weights, sims = 1000,
     if (is.numeric(weights)) {
       numeric.input <- TRUE
     } else {
-      stop("weights argument must be either the name of a column in the data frame or a numeric vector.")
+      stop("weights argument must be either the name of a column in the\n",
+           "data frame or a numeric vector.")
     }
   }
 
+  if (is.null(data)) {
+    data <- model.frame(model)
+  }
   data <- as.data.frame(data)
   if (numeric.input == TRUE) {
     data$weight <- weights
@@ -365,7 +365,9 @@ pf_sv_test <- function(model, data, weights, sims = 1000,
 
     data <- as.data.frame(data)[indices,]
     newmod <- update(model, data = data)
-    wts <- data[[wts]]
+    cases <- complete.cases(model.frame(formula(newmod), data = data,
+                                        na.action = na.pass))
+    wts <- data[cases, wts]
 
     c1 <- cor(resid(newmod), wts)
     c2 <- cor(resid(newmod)^2, wts)
@@ -378,10 +380,15 @@ pf_sv_test <- function(model, data, weights, sims = 1000,
   bo <- boot::boot(data = data, statistic = corfun, R = sims, model = model,
                    wts = weights, numeric.input = numeric.input)
 
+  # Need to filter out missing cases from weights vectors
+  cases <- complete.cases(model.frame(formula(model), data = data,
+                                      na.action = na.pass))
+  wts <- data[cases, weights]
+
   # Getting the in-sample correlations
-  c1 <- cor(resid(model), data[[weights]])
-  c2 <- cor(resid(model)^2, data[[weights]])
-  c3 <- cor(resid(model)^3, data[[weights]])
+  c1 <- cor(resid(model), wts)
+  c2 <- cor(resid(model)^2, wts)
+  c3 <- cor(resid(model)^3, wts)
 
   # Now saving the Fisher's z-transformed versions of them
   z1 <- atanh(c1)
@@ -420,14 +427,14 @@ pf_sv_test <- function(model, data, weights, sims = 1000,
 print.pf_sv_test <- function (x, ...) {
 
   cat("\nPfeffermann-Sverchkov test of sample weight ignorability \n\n")
-  cat("Residual correlation = ", round(x$r1, x$digits), ", p = ",
-      round(x$p1, x$digits), "\n", sep = "")
-  cat("Squared residual correlation = ", round(x$r2, x$digits), ", p = ",
-      round(x$p2, x$digits), "\n", sep = "")
-  cat("Cubed residual correlation = ", round(x$r3, x$digits), ", p = ",
-      round(x$p3, x$digits), "\n", sep = "")
+  cat("Residual correlation = ", num_print(x$r1, x$digits), ", p = ",
+      num_print(x$p1, x$digits), "\n", sep = "")
+  cat("Squared residual correlation = ", num_print(x$r2, x$digits), ", p = ",
+      num_print(x$p2, x$digits), "\n", sep = "")
+  cat("Cubed residual correlation = ", num_print(x$r3, x$digits), ", p = ",
+      num_print(x$p3, x$digits), "\n", sep = "")
 
-  cat("\nA significant correlation may indicate biased estimates in",
+  cat("\nA significant correlation may indicate biased estimates\nin",
       "the unweighted model.\n")
 
 }
@@ -442,7 +449,8 @@ print.pf_sv_test <- function (x, ...) {
 #'
 #' @param model The fitted model, without weights
 #'
-#' @param data The data frame with the data fed to the fitted model and the weights
+#' @param data The data frame with the data fed to the fitted model and the
+#'  weights
 #'
 #' @param weights The name of the weights column in \code{model}'s data frame
 #'   or a vector of weights equal in length to the number of observations
@@ -508,7 +516,7 @@ print.pf_sv_test <- function (x, ...) {
 
 weights_tests <- function(model, weights, data, model_output = TRUE,
                           test = NULL, sims = 1000,
-                          digits = getOption("jtools-digits", default = 3)) {
+                          digits = getOption("jtools-digits", default = 2)) {
 
   # Create list of acceptable arguments to both functions
   wtnames <- names(formals(wgttest))
@@ -541,6 +549,7 @@ weights_tests <- function(model, weights, data, model_output = TRUE,
 print.weights_tests <- function(x, ...) {
 
   print(x$wt)
+  cat("---")
   print(x$pf)
 
 }
@@ -569,28 +578,31 @@ print.weights_tests <- function(x, ...) {
 #'   associated t- and p-values. See details for some considerations when doing
 #'   null hypothesis testing with complex survey correlations.
 #'
-#' @param bootn If \code{sig.stats} is TRUE, this defines the number of bootstraps
-#'   to be run to generate the standard errors and p-values. For large values and
-#'   large datasets, this can contribute considerably to processing time.
+#' @param bootn If \code{sig.stats} is TRUE, this defines the number of
+#'  bootstraps to be run to generate the standard errors and p-values. For
+#'  large values and large datasets, this can contribute considerably to
+#'  processing time.
 #'
 #' @param mean1 If \code{sig.stats} is TRUE, it is important to know whether the
-#'   sampling weights should have a mean of 1. That is, should the standard errors
-#'   be calculated as if the number of rows in your dataset is the total number of
-#'   observations (TRUE) or as if the sum of the weights in your dataset is the
-#'   total number of observations (FALSE)?
+#'   sampling weights should have a mean of 1. That is, should the standard
+#'   errors be calculated as if the number of rows in your dataset is the total
+#'   number of observations (TRUE) or as if the sum of the weights in your
+#'   dataset is the total number of observations (FALSE)?
 #'
 #' @param ... Additional arguments passed to \code{\link[survey]{svyvar}}.
 #'
 #' @details
-#'   This function extends the \code{survey} package by calculating the correlations
-#'   for user-specified variables in survey design and returning a correlation matrix.
+#'   This function extends the \code{survey} package by calculating the
+#'   correlations for user-specified variables in survey design and returning a
+#'   correlation matrix.
 #'
-#'   Using the \code{\link[weights]{wtd.cor}} function, this function also returns
-#'   standard errors and p-values for the correlation terms using a sample-weighted
-#'   bootstrapping procedure. While correlations do not require distributional
-#'   assumptions, hypothesis testing (i.e., \eqn{r > 0}) does. The appropriate way to
-#'   calculate standard errors and use them to define a probability is not straightforward
-#'   in this scenario since the weighting causes heteroskedasticity, thereby violating
+#'   Using the \code{\link[weights]{wtd.cor}} function, this function also
+#'   returns standard errors and p-values for the correlation terms using a
+#'   sample-weighted bootstrapping procedure. While correlations do not require
+#'   distributional assumptions, hypothesis testing (i.e., \eqn{r > 0}) does.
+#'   The appropriate way to calculate standard errors and use them to define a
+#'   probability is not straightforward in this scenario since the weighting
+#'   causes heteroskedasticity, thereby violating
 #'   an assumption inherent in the commonly used methods for converting Pearson's
 #'   correlations into t-values. The method provided here is defensible, but if
 #'   reporting in scientific publications the method should be spelled out.
@@ -614,9 +626,10 @@ print.weights_tests <- function(x, ...) {
 #'
 #' @seealso \code{\link[weights]{wtd.cor}}, \code{\link[survey]{svyvar}}
 #'
-#' @note This function was designed in part on the procedure recommended by Thomas
-#'   Lumley, the author of the survey package, on
-#'   \href{http://stackoverflow.com/questions/34418822/pearson-correlation-coefficient-in-rs-survey-package#41031088}{Stack Overflow}. However, he has not reviewed or endorsed this implementation.
+#' @note This function was designed in part on the procedure recommended by
+#'  Thomas Lumley, the author of the survey package, on
+#'   \href{http://stackoverflow.com/questions/34418822/pearson-correlation-coefficient-in-rs-survey-package#41031088}{Stack Overflow}. However, he has
+#'   not reviewed or endorsed this implementation.
 #'   All defects are attributed to the author.
 #'
 #' @examples
@@ -624,15 +637,16 @@ print.weights_tests <- function(x, ...) {
 #'  library(survey)
 #'  data(api)
 #'  # Create survey design object
-#'  dstrat <- svydesign(id = ~1,strata = ~stype, weights = ~pw, data = apistrat,
-#'                      fpc=~fpc)
+#'  dstrat <- svydesign(id = ~1, strata = ~stype, weights = ~pw,
+#'                      data = apistrat, fpc = ~fpc)
 #'
 #'  # Print correlation matrix
-#'  svycor(~api00+api99+dnum, design = dstrat)
+#'  svycor(~api00 + api99 + dnum, design = dstrat)
 #'
 #'  # Save the results, extract correlation matrix
-#'  out <- svycor(~api00+api99+dnum, design = dstrat)
+#'  out <- svycor(~api00 + api99 + dnum, design = dstrat)
 #'  out$cors
+#'
 #' }
 #'
 #' @importFrom stats cov2cor model.frame na.pass weights
@@ -682,9 +696,14 @@ svycor <- function(formula, design, na.rm = FALSE,
   if (sig.stats == FALSE) {
     return(c)
   } else {
+
+    if (!requireNamespace("weights", quietly = TRUE)) {
+      stop("p-value calculations require the 'weights' package.")
+    }
+
     # Use wtd.cor
-    wcors <- weights::wtd.cor(mf, weight=wts, bootse=TRUE, mean1=mean1,
-                              bootn=bootn, bootp=T)
+    wcors <- weights::wtd.cor(mf, weight = wts, bootse = TRUE, mean1 = mean1,
+                              bootn = bootn, bootp = TRUE)
 
     c$cors <- wcors$correlation
     c$p.values <- wcors$p.value
@@ -733,7 +752,7 @@ print.svycor <- function(x, ...) {
     diag(pm)[] <- ""
 
     # Combine matrix of estimates and significance stars
-    cm[] <- paste(cm[], pm[], sep="")
+    cm[] <- paste(cm[], pm[], sep = "")
 
     print(as.table(cm))
 
@@ -806,7 +825,7 @@ svysd <- function(formula, design, na.rm = FALSE,
 
   sds <- c() # Stores the values extracted next
   # Extract variance for each term from matrix
-  for (i in seq_len(length(terms))) {
+  for (i in seq_along(terms)) {
     sds <- c(sds, v[i,i])
   }
 
