@@ -2,7 +2,8 @@
 required <- c("survey", "huxtable", "sandwich", "cowplot")
 if (!all(sapply(required, requireNamespace, quietly = TRUE)))
   knitr::opts_chunk$set(eval = FALSE)
-knitr::opts_chunk$set(message = F, warning = F, fig.width = 6, fig.height = 5)
+knitr::opts_chunk$set(message = F, warning = F, fig.width = 6, fig.height = 5,
+                      fig.options = list(type = "cairo"))
 library(jtools)
 
 ## ------------------------------------------------------------------------
