@@ -3,8 +3,7 @@ required <- c("survey", "huxtable", "broom", "lme4", "quantreg")
 if (!all(sapply(required, requireNamespace, quietly = TRUE)))
   knitr::opts_chunk$set(eval = FALSE)
 knitr::opts_chunk$set(message = F, warning = F, fig.width = 6, fig.height = 5,
-                      render = knitr::normal_print
-                      )
+                      render = knitr::normal_print)
 library(jtools)
 
 ## ------------------------------------------------------------------------
