@@ -445,7 +445,7 @@ class TestGetter(unittest.TestCase):
         self.assertEqual(value, Query("$inject(@value)").single({"value": value}))
 
     def test_valid_names(self):
-        keys = ["_", "-", "range[0]", "23", "123asdf", "!not"]
+        keys = ["_", "-", "23", "123asdf", "bill_1234_asdf-24234"]
         value = [1, 2]
         for key in keys:
             self.assertEqual(value, Query(key, convert_ints=False).single({key: value}))
